pub struct HoverResultDTO {
pub Contents: Vec<IMarkdownStringDTO>,
pub Range: Option<RangeDTO>,
}Expand description
A serializable struct that represents the content to be displayed in a
hover tooltip, analogous to vscode.Hover.
Fields
Contents: Vec<IMarkdownStringDTO>The contents of the hover, which can be one or more markdown strings.
Range: Option<RangeDTO>An optional range to which this hover applies. When not specified, the range of the word at the request position is used.